netapp_ontap.models.aggregate_block_storage_hybrid_cache API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.aggregate_block_storage_hybrid_cache`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class AggregateBlockStorageHybridCacheSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the AggregateBlockStorageHybridCache object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `disk_count: Size GET POST PATCH`

    Number of disks used in the cache tier of the aggregate. Only provided when hybrid_cache.enabled is 'true'.

    Example: 6

  `disk_type: str GET`

    Type of disk being used by the aggregate's cache tier.

    Valid choices:

    - fc
    - lun
    - nl_sas
    - nvme_ssd
    - sas
    - sata
    - scsi
    - ssd
    - ssd_cap
    - ssd_zns
    - vm_disk
  `enabled: bool GET`

    Specifies whether the aggregate uses HDDs with SSDs as a cache.

  `raid_size: Size GET POST PATCH`

    Option to specify the maximum number of disks that can be included in a RAID group.

    Example: 24

  `raid_type: str GET POST PATCH`

    RAID type for SSD cache of the aggregate. Only provided when hybrid_cache.enabled is 'true'.

    Valid choices:

    - raid_dp
    - raid_tec
    - raid4
  `simulated_raid_groups: List[AggregateBlockStorageHybridCacheSimulatedRaidGroups] GET POST PATCH`

    The simulated_raid_groups field of the aggregate_block_storage_hybrid_cache.

  `size: Size GET`

    Total usable space in bytes of SSD cache. Only provided when hybrid_cache.enabled is 'true'.

    Example: 1612709888

  `storage_pools: List[AggregateBlockStorageHybridCacheStoragePools] GET POST PATCH`

    List of storage pool properties and allocation_units_count for aggregate.

  `used: Size GET`

    Space used in bytes of SSD cache. Only provided when hybrid_cache.enabled is 'true'.

    Example: 26501122